==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/de_DE.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivitäten",
    "An error occurred while loading activities" : "Es ist ein Fehler beim Laden der Aktivitäten aufgetreten",
    "No activity yet" : "Bislang keine Aktivitäten",
    "Load more activities" : "Weitere Aktivitäten laden",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "Home" : "Home",
    "{name} (invisible)" : "{name} (unsichtbar)",
    "{name} (restricted)" : "{name} (eingeschränkt)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzugekommenes, Änderungen und Freigaben an",
    "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "Open file" : "Datei öffnen",
    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
    "Your feed URL is invalid" : "Ihre Feed-URL ist ungültig",
    "Your settings have been updated." : "Ihre Einstellungen wurden aktualisiert.",
    "Settings have been updated." : "Die Einstellungen wurden aktualisiert.",
    "Mail" : "E-Mail",
    "Stream" : "Stream",
    "All activities" : "Alle Aktivitäten",
    "By others" : "Von anderen",
    "By you" : "Von Ihnen",
    "\"remote user\"" : "„Externer Benutzer“",
    "Hello %s" : "Hallo %s",
    "Hello %s," : "Hallo %s,",
    "There was some activity at %s" : "Es gab Aktivitäten bei %s",
    "_and %n more _::_and %n more _" : ["und %n weiterer","und %n weitere"],
    "Activity notification" : "Benachrichtigung über die Aktivitäten",
    ", " : ", ",
    "%s and %s" : "%s und %s",
    "Activity" : "Aktivität",
    "Activity feed" : "Feed der Aktivitäten",
    "Send activity emails" : "E-Mails zu Aktivitäten senden",
    "Default settings" : "Standardeinstellungen",
    "Configure the default activity settings for new users." : "Nehmen Sie  die Voreinstellungen der Aktivitäten für neue Benutzer vor.",
    "List your own actions in the stream" : "Ihre eigenen Aktivitäten im Stream auflisten",
    "Notify about your own actions via email" : "Über Ihre eigenen Aktivitäten via E-Mail benachrichtigen",
    "You need to set up your email address before you can receive notification emails." : "Bevor Sie E-Mail-Benachrichtigungen empfangen können, müssen Sie Ihre E-Mail-Adresse einrichten.",
    "Send emails:" : "E-Mails senden:",
    "As soon as possible" : "So bald wie möglich",
    "Hourly" : "stündlich",
    "Daily" : "täglich",
    "Weekly" : "wöchentlich",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Wählen Sie für welche Aktivitäten E-Mails empfangen und welche Aktivitäten in Ihrem Feed angezeigt werden.",
    "Choose which activities you want to see in your stream." : "Wählen Sie aus, welche Aktivitäten in Ihrem Feed angezeigt werden.",
    "Settings" : "Einstellungen",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "RSS feed" : "RSS-Feed",
    "No more events to load" : "Keine weiteren Ereignisse zu laden",
    "Files" : "Dateien",
    "Error loading activities" : "Fehler beim Laden der Aktivitäten",
    "No activities" : "Keine Aktivitäten",
    "You are receiving this email because the following things happened at %s" : "Sie erhalten diese E-Mail, da folgende Dinge auf %s geschehen sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weitere","* und %n weitere"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/de_DE.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Aktivitäten",
    "An error occurred while loading activities" : "Es ist ein Fehler beim Laden der Aktivitäten aufgetreten",
    "No activity yet" : "Bislang keine Aktivitäten",
    "Load more activities" : "Weitere Aktivitäten laden",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "Home" : "Home",
    "{name} (invisible)" : "{name} (unsichtbar)",
    "{name} (restricted)" : "{name} (eingeschränkt)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzugekommenes, Änderungen und Freigaben an",
    "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "Open file" : "Datei öffnen",
    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
    "Your feed URL is invalid" : "Ihre Feed-URL ist ungültig",
    "Your settings have been updated." : "Ihre Einstellungen wurden aktualisiert.",
    "Settings have been updated." : "Die Einstellungen wurden aktualisiert.",
    "All activities" : "Alle Aktivitäten",
    "By others" : "Von anderen",
    "By you" : "Von Ihnen",
    "\"remote user\"" : "„Externer Benutzer“",
    "Activity notification for %s" : "Benachrichtigung zu Aktivitäten für %s",
    "Hello %s" : "Hallo %s",
    "Hello %s," : "Hallo %s,",
    "There was some activity at %s" : "Es gab Aktivitäten bei %s",
    "_and %n more _::_and %n more _" : ["und %n weiterer","und %n weitere"],
    ", " : ", ",
    "%s and %s" : "%s und %s",
    "Mail" : "E-Mail",
    "Stream" : "Stream",
    "Activity" : "Aktivität",
    "Activity feed" : "Feed der Aktivitäten",
    "Send activity emails" : "E-Mails zu Aktivitäten senden",
    "Default settings" : "Standardeinstellungen",
    "Configure the default activity settings for new users." : "Nehmen Sie  die Voreinstellungen der Aktivitäten für neue Benutzer vor.",
    "List your own actions in the stream" : "Ihre eigenen Aktivitäten im Stream auflisten",
    "Notify about your own actions via email" : "Über Ihre eigenen Aktivitäten via E-Mail benachrichtigen",
    "You need to set up your email address before you can receive notification emails." : "Bevor Sie E-Mail-Benachrichtigungen empfangen können, müssen Sie Ihre E-Mail-Adresse einrichten.",
    "Send emails:" : "E-Mails senden:",
    "As soon as possible" : "So bald wie möglich",
    "Hourly" : "stündlich",
    "Daily" : "täglich",
    "Weekly" : "wöchentlich",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Wählen Sie für welche Aktivitäten E-Mails empfangen und welche Aktivitäten in Ihrem Feed angezeigt werden.",
    "Choose which activities you want to see in your stream." : "Wählen Sie aus, welche Aktivitäten in Ihrem Feed angezeigt werden.",
    "Settings" : "Einstellungen",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "RSS feed" : "RSS-Feed",
    "No more events to load" : "Keine weiteren Ereignisse zu laden",
    "Files" : "Dateien",
    "Activity notification" : "Benachrichtigung über die Aktivitäten"
},
"nplurals=2; plural=(n != 1);");
